aboutsummaryrefslogtreecommitdiffstats
path: root/tap-protocolinfo.c
diff options
context:
space:
mode:
authorAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
committerAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
commitf68d6e4c8cc08f1fe570d15e2185d339c81883b8 (patch)
tree2b6a6711cc2ff394c41a98f47a388466a433bccd /tap-protocolinfo.c
parent996d4db495e60df8a627097e3885acdce209132c (diff)
Ethereal->Wireshark
svn path=/trunk/; revision=18235
Diffstat (limited to 'tap-protocolinfo.c')
-rw-r--r--tap-protocolinfo.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tap-protocolinfo.c b/tap-protocolinfo.c
index af81463745..3f4cc3108b 100644
--- a/tap-protocolinfo.c
+++ b/tap-protocolinfo.c
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides Protocol Column Info tap for tethereal */
#ifdef HAVE_CONFIG_H
# include "config.h"
@@ -67,7 +67,7 @@ protocolinfo_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt, const vo
* and, if so, we report that error and exit.
*/
if (pinfo->cinfo == NULL) {
- fprintf(stderr, "tethereal: the proto,colinfo tap doesn't work if the columns aren't being printed.\n");
+ fprintf(stderr, "twireshark: the proto,colinfo tap doesn't work if the columns aren't being printed.\n");
exit(1);
}
gp=proto_get_finfo_ptr_array(edt->tree, rs->hf_index);
@@ -103,13 +103,13 @@ protocolinfo_init(const char *optarg, void* userdata _U_)
}
}
if(!field){
- fprintf(stderr, "tethereal: invalid \"-z proto,colinfo,<filter>,<field>\" argument\n");
+ fprintf(stderr, "twireshark: invalid \"-z proto,colinfo,<filter>,<field>\" argument\n");
exit(1);
}
hfi=proto_registrar_get_byname(field);
if(!hfi){
- fprintf(stderr, "tethereal: Field \"%s\" doesn't exist.\n", field);
+ fprintf(stderr, "twireshark: Field \"%s\" doesn't exist.\n", field);
exit(1);
}
@@ -126,7 +126,7 @@ protocolinfo_init(const char *optarg, void* userdata _U_)
error_string=register_tap_listener("frame", rs, rs->filter, NULL, protocolinfo_packet, NULL);
if(error_string){
/* error, we failed to attach to the tap. complain and clean up */
- fprintf(stderr, "tethereal: Couldn't register proto,colinfo tap: %s\n",
+ fprintf(stderr, "twireshark: Couldn't register proto,colinfo tap: %s\n",
error_string->str);
g_string_free(error_string, TRUE);
if(rs->filter){
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides Protocol Column Info tap for tethereal */
+/* This module provides Protocol Column Info tap for twireshark */
#ifdef HAVE_CONFIG_H
# include "config.h"